@@ -10,18 +10,24 @@ from flexget.task import TaskAbort
 log = logging.getLogger('task_queue')
 
 
-class TaskQueue(threading.Thread):
+class TaskQueue(object):
     """
     Task processing thread.
     Only executes one task at a time, if more are requested they are queued up and run in turn.
     """
     def __init__(self):
-        super(TaskQueue, self).__init__(name='task_queue')
-        self.daemon = True
         self.run_queue = Queue.PriorityQueue()
         self._shutdown_now = False
         self._shutdown_when_finished = False
 
+        # We don't override `threading.Thread` because debugging this seems unsafe with pydevd.
+        # Overriding __len__(self) seems to cause a debugger deadlock.
+        self._thread = threading.Thread(target=self.run, name='task_queue')
+        self._thread.daemon = True
+
+    def start(self):
+        self._thread.start()
+
     def run(self):
         try:
             while not self._shutdown_now:
@@ -72,11 +78,11 @@ class TaskQueue(threading.Thread):
         Allows abortion of task queue with ctrl-c
         """
         try:
-            while self.is_alive():
+            while self._thread.is_alive():
                 time.sleep(0.5)
         except KeyboardInterrupt:
             log.error('Got ctrl-c, shutting down after this task finishes')
             self.shutdown(finish_queue=False)
             # We still wait to finish cleanly, pressing ctrl-c again will abort
-            while self.is_alive():
+            while self._thread.is_alive():
                 time.sleep(0.5)
